==> pulseaudio-qt-1.0.1.tar.xz: pulseaudio-qt-1.0.1/src/port_p.h <==
/*
    Copyright 2018 Nicolas Fella <nicolas.fella@gmx.de>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#pragma once

#include "port.h"
#include "profile_p.h"
#include <pulse/def.h>

namespace PulseAudioQt
{

class PortPrivate
{
public:
    explicit PortPrivate(Port *q);
    virtual ~PortPrivate();

    Port *q;

    template<typename PAInfo>
    void setInfo(const PAInfo *info)
    {
        Profile::Availability newAvailability;
            switch (info->available) {
            case PA_PORT_AVAILABLE_NO:
                newAvailability = Profile::Unavailable;
                break;
            case PA_PORT_AVAILABLE_YES:
                newAvailability = Profile::Available;
                break;
            default:
                newAvailability = Profile::Unknown;
            }
            q->Profile::d->setCommonInfo(info, newAvailability);
    }
};
}

==> pulseaudio-qt_1.2.orig.tar.xz: pulseaudio-qt-1.2/src/port_p.h <==
/*
    Copyright 2018 Nicolas Fella <nicolas.fella@gmx.de>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#pragma once

#include "port.h"
#include "profile_p.h"
#include <pulse/def.h>

namespace PulseAudioQt
{
class PortPrivate
{
public:
    explicit PortPrivate(Port *q);
    virtual ~PortPrivate();

    Port *q;

    template<typename PAInfo> void setInfo(const PAInfo *info)
    {
        Profile::Availability newAvailability;
        switch (info->available) {
        case PA_PORT_AVAILABLE_NO:
            newAvailability = Profile::Unavailable;
            break;
        case PA_PORT_AVAILABLE_YES:
            newAvailability = Profile::Available;
            break;
        default:
            newAvailability = Profile::Unknown;
        }
        q->Profile::d->setCommonInfo(info, newAvailability);
    }
};
}
